@@ -5,6 +5,7 @@ from decimal import Decimal
 import datetime
 import time
 import os
+import operator
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.report import Report
@@ -1415,7 +1416,9 @@ class TrialBalance(Report):
         periods = period_obj.browse(end_period_ids)
 
         localcontext['accounts'] = accounts
+        periods.sort(key=operator.attrgetter('start_date'))
         localcontext['start_period'] = periods[0]
+        periods.sort(key=operator.attrgetter('end_date'))
         localcontext['end_period'] = periods[-1]
         localcontext['company'] = company
         localcontext['digits'] = company.currency.digits
@@ -2069,7 +2072,8 @@ class ThirdPartyBalance(Report):
         localcontext['company'] = company
         localcontext['digits'] = company.currency.digits
         localcontext['fiscalyear'] = datas['form']['fiscalyear']
-        line_query, _ = move_line_obj.query_get()
+        with Transaction().set_context(context=localcontext):
+            line_query, _ = move_line_obj.query_get()
         if datas['form']['posted']:
             posted_clause = "AND m.state = 'posted' "
         else:
@@ -2217,7 +2221,8 @@ class AgedBalance(Report):
         localcontext['digits'] = company.currency.digits
         localcontext['fiscalyear'] = datas['form']['fiscalyear']
         localcontext['posted'] = datas['form']['posted']
-        line_query, _ = move_line_obj.query_get()
+        with Transaction().set_context(context=localcontext):
+            line_query, _ = move_line_obj.query_get()
 
         terms = (datas['form']['term1'],
                   datas['form']['term2'],
